# CoolBar
Dynamic Python Progress Bar
[CoolBar GitHub](https://github.com/ReloadingBee/CoolBar)

## Table of Contents
- [Introduction](#introduction)
- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)

## Introduction
CoolBar is a Python3 package that aims to provide users with a _cool_ progress bar for terminals.

## Features
- Scalable progress bar
- Time tracking (eta, time per item, total time)
- Animations
- Ease of use

## Installation
`pip install CoolBar`

## Usage

...

## Contributing
If you wish to contribute, you're 100% welcome to!

Just fork this project and start creating. Once you're done, just make a pull request, and I'll consider merging 🙂

## License
This project is licensed under the Apache License 2.0 - see the [LICENSE](https://github.com/ReloadingBee/CoolBar/blob/main/LICENSE) file for details.
